@@ -8,7 +8,7 @@ Perl::Dist::WiX::BuildPerl - 4th generation Win32 Perl distribution builder
 
 =head1 VERSION
 
-This document describes Perl::Dist::WiX::BuildPerl version 1.200_100.
+This document describes Perl::Dist::WiX::BuildPerl version 1.200_101.
 
 =head1 DESCRIPTION
 
@@ -39,13 +39,15 @@ use Perl::Dist::WiX::Asset::Perl qw();
 use Perl::Dist::WiX::Toolchain qw();
 use File::List::Object qw();
 
-our $VERSION = '1.200_100';
+our $VERSION = '1.200_101';
 $VERSION =~ s/_//sm;
 
+# Keys are what's in the filename, with - being converted to ::.
+# Values are the actual module to use to check whether it's in core.
 Readonly my %CORE_MODULE_FIX => (
 	'IO::Compress'         => 'IO::Compress::Base',
 	'Filter'               => 'Filter::Util::Call',
-	'Pod'                  => 'Pod::Man',
+	'podlators'            => 'Pod::Man',
 	'Text'                 => 'Text::Tabs',
 	'PathTools'            => 'Cwd',
 	'Scalar::List::Utils'  => 'List::Util',
@@ -56,10 +58,17 @@ Readonly my %CORE_MODULE_FIX => (
 	'LWP::UserAgent'       => 'LWP',
 );
 
-Readonly my %CORE_PACKLIST_FIX =>
-  ( 'IO::Compress::Base' => 'IO::Compress', );
+# Keys are the module name after processing against %CORE_MODULE_FIX.
+# Values are the directory name the .packlist file is in, with
+# / being converted to ::.
+Readonly my %CORE_PACKLIST_FIX => (
+	'IO::Compress::Base' => 'IO::Compress',
+	'Pod::Man'           => 'Pod',
+);
 
-# Modules to delay.
+# List of modules to delay building until last when upgrading all CPAN
+# modules (they depend on upgraded versions of modules that originally
+# were upgraded after them.)
 Readonly my @MODULE_DELAY => qw(
   CPANPLUS::Dist::Build
   File::Fetch
@@ -275,7 +284,7 @@ sub install_cpan_upgrades { ## no critic(ProhibitExcessComplexity)
 	# Install dev version of CPAN if we haven't already.
 	if ( not $self->fragment_exists('CPAN') ) {
 		$self->install_distribution(
-			name             => 'ANDK/CPAN-1.94_56.tar.gz',
+			name             => 'ANDK/CPAN-1.94_58.tar.gz',
 			mod_name         => 'CPAN',
 			makefilepl_param => ['INSTALLDIRS=perl'],
 			buildpl_param    => [ '--installdirs', 'core' ],
@@ -545,10 +554,15 @@ sub _create_perl_toolchain {
 	# Prefetch and predelegate the toolchain so that it
 	# fails early if there's a problem
 	$self->trace_line( 1, "Pregenerating toolchain...\n" );
+	my $force = {};
+	if ( $self->perl_version =~ m/\A512/ms ) {
+		$force = { 'Pod::Text' => 'RRA/podlators-2.3.1.tar.gz' };
+	}
 	my $toolchain = Perl::Dist::WiX::Toolchain->new(
 		perl_version => $self->perl_version_literal(),
 		cpan         => $cpan->as_string(),
 		bits         => $self->bits(),
+		force        => $force,
 	) or PDWiX->throw('Failed to resolve toolchain modules');
 	if ( not eval { $toolchain->delegate(); 1; } ) {
 		PDWiX::Caught->throw(
@@ -917,14 +931,9 @@ sub install_perl_toolchain {
 			# 1.9402 fails its tests... ANDK says it's a test bug.
 			# Alias agrees that we include 1.94_51 because of the fix
 			# for the Win32 file:// bug.
-			$dist  = 'ANDK/CPAN-1.94_56.tar.gz';
+			$dist  = 'ANDK/CPAN-1.94_58.tar.gz';
 			$force = 1;
 		}
-		if ( $dist =~ /Win32API-Registry-0 [.] 31/msx ) {
-
-			# 0.31 does not include a Makefile.PL.
-			$dist = 'BLM/Win32API-Registry-0.30.tar.gz';
-		}
 		if ( $dist =~ /ExtUtils-MakeMaker-/msx ) {
 
 			# There are modules that overwrite portions of this one.
